<!DOCTYPE TS><TS>
<context>
    <name>DjVuViewer</name>
    <message>
        <source>Unexpected end of file encountered</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDAboutDialog</name>
    <message>
        <source>About DjView</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu standalone viewer
and browser plugin.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version DjVuLibre-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDBase</name>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will export the DjVu image in either &apos;Raw %1&apos;
or &apos;ASCII %2&apos; format. Which one do you prefer?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting DjVu image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Raw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ascii</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select export file name...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please stand by...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu: Exporting image...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDCachePrefs</name>
    <message>
        <source>Off screen cache size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decoded pages cache:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Caches:&lt;/b&gt;&lt;br&gt;There are several caches in &lt;i&gt;djview&lt;/i&gt;.&lt;ul&gt;&lt;li&gt;The &lt;i&gt;off screen cache&lt;/i&gt; stores image data located outside the visible area. This cache makes panning smoother.&lt;/li&gt;&lt;li&gt;The &lt;i&gt;decoded page cache&lt;/i&gt; contains partially decoded pages. It provides faster response times when navigating a multipage document or when returning to a previously viewed page. Clearing this cache might be useful to reflect a change in the page data without restarting the DjVu viewer.&lt;/li&gt;&lt;/ul&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDDocInfo</name>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information on page </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Information on file </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait while I&apos;m downloading the data...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page &amp;Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Goto to page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu multipage document info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BUNDLED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obsolete BUNDLED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>INDIRECT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obsolete INDEXED</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SINGLE_PAGE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Total size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pages:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Files:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Double click any page from the list to view it.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Press the right mouse button to see popup menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Goto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order #</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pages Covered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;All Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDDocNameDialog</name>
    <message>
        <source>All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select DjVu document file name...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File &apos;%1&apos; already exists.
Are you sure you want to overwrite it?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu document file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDDocSaver</name>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Would you like to save the document in
BUNDLED format (one file) or in INDIRECT
format (many files: ideal for web browsing)?
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Bundled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Indirect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the document file name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the name of the main document file.
All other files will be saved in the same directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The chosen name coincides with the name of
one of the files composing this multipage document.
Please choose another name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait while the file is being downloaded...        </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data stream from Netscape has been stopped.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait while all pages are being loaded...        </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDFileFormatDialog</name>
    <message>
        <source>DjVu page file format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It seems that contents of this page are scattered over more than one file.
You have the following options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create all these files. This is useful if you plan to save several page to insert them into another document. The shared files will remain shared.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pack all these files into one bundle (so called BUNDLED format). This is convenient because you will have only one file and will still be able to split it into many when necessary.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merge chunks from all files and store them into one file. Use this if you need the simplest structure of the file and you do not plan to separate the chunks again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDFilesListDialog</name>
    <message>
        <source>DjVu: File list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following files will be created in directory &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDGammaDispl</name>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDGammaPrefs</name>
    <message>
        <source>Screen color correction.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust slider until
gray shades look similar.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Darker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lighter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printer color correction.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic color matching.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Screen gamma correction:&lt;/b&gt;&lt;br&gt;The best color rendition is achieved by adjusting the gamma correction slider and choosing the position that makes the gray square as uniform as possible.&lt;p&gt;&lt;b&gt;Printer color correction:&lt;/b&gt;&lt;br&gt;The &lt;i&gt;automatic color matching&lt;/i&gt; option works best with PostScript printers and ICC profiled printers. The slider might be useful in other cases.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDHlinkPrefs</name>
    <message>
        <source>Disable hyperlink popup messages.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw hyperlinks using simple border.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;Show all hyperlinks&quot; key:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Hyperlinks:&lt;/b&gt;&lt;ul&gt;&lt;li&gt;Hyperlinks are hilited when the mouse hovers above the hyperlink region or when the the key combination specified in the &lt;i&gt;show all hyperlinks&lt;/i&gt; box is depressed.&lt;/li&gt;&lt;li&gt;The &lt;i&gt;disable hyperlink popups&lt;/i&gt; option hides the popup messages optionally associated with the hyperlinks.&lt;/li&gt;&lt;li&gt;The &lt;i&gt;draw using simple border&lt;/i&gt; option selects simpler hiliting effects.&lt;/li&gt;&lt;/ul&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDJView</name>
    <message>
        <source>DJVIEW --- DjVuLibre-%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu document viewer.

Usage: djview &lt;options_list&gt; &lt;file_name&gt;
Options:
     -file &lt;file_name&gt;       - alternative way to specify file name
     -page &lt;page_num&gt;        - number of the page to display
     -help                   - print this message
     -style=motif            - Motif look and feel
     -style=windows          - Win95 look and feel
     -fullscreen, -fs        - run in full screen mode
     -geometry &lt;geometry&gt;    - specify X11 startup geometry
     -display &lt;display&gt;      - specify X11 display name
     -fn &lt;fontname&gt;          - specify Qt/X11 default font
     -bg &lt;color&gt;             - specify Qt/X11 default background color
     -fg &lt;color&gt;             - specify Qt/X11 default foreground color
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>     -btn &lt;color&gt;            - specify Qt/X11 default button color
     -visual TrueColor       - forces use of a TrueColor visual (8 bit display)
     -ncols &lt;count&gt;          - limit color palette use (8 bit display)
     -cmap                   - install private colormap (8 bit display)
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>     -debug[=&lt;level&gt;]        - print debug information
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>     -fix                    - fix configuration of Netscape helpers

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>djview: warning: duplicate page specification
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>djview: warning: unrecognized option &apos;%1&apos;
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>djview: warning: duplicate filename specification
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>djview: warning: illegal page number
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>djview: warning: page specification without a file name
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDLensPrefs</name>
    <message>
        <source>Control key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Middle mouse button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> pixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magnification: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To activate press: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Magnification lens:&lt;/b&gt;&lt;br&gt;The &lt;i&gt;magnification lens&lt;/i&gt; appears under the mouse pointer when you press the selected key.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDMessageQueue</name>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDMimeDialog</name>
    <message>
        <source>DjVu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We have just found that your configuration files &quot;.mime.types&quot; and &quot;.mailcap&quot; should be updated in order for the DjVu plugin to work properly. The invalid information can prevent Netscape from correctly displaying DjVu documents and can make Netscape use incorrect MIME type when sending DjVu documents via e-mail.

Would  you like to update these files now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next time &amp;check this again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next time do the update &amp;silently</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Never do this check again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDNavGotoPage</name>
    <message>
        <source>DjVu: Goto Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Goto page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDOptimPrefs</name>
    <message>
        <source>Favor fast magnifications for &quot;Fit&quot; resolutions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable fast thumbnails.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optimize images for LCD displays.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Optimizations:&lt;/b&gt;&lt;ul&gt;&lt;li&gt;The &lt;i&gt;fast magnification&lt;/i&gt; option selects integer magnifications that require less computing resources.&lt;/li&gt;&lt;li&gt;The &lt;i&gt;fast thumbnails&lt;/i&gt; option never compute thumbnails unless the page data is already cached. This cuts network traffic that might be otherwise unnecessary.&lt;/li&gt;&lt;li&gt;The &lt;i&gt;LCD display&lt;/i&gt; option might improve the image quality on certain LCD displays.&lt;/li&gt;&lt;/ul&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDPageSaver</name>
    <message>
        <source>All files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot save the page because data is missing.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDPane</name>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDPrintDialog</name>
    <message>
        <source>of the current page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>of the custom pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>of the document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>of the window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale to Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One to One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Zoom:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>rectos and versos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>rectos only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>versos only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select output file name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No custom pages were specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File &apos;%1&apos; already exists.
Are you sure you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot launch specified print command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print quality will be lower because
PostScript level 1 cannot perform
automatic color matching.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu Print Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>What to print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> copies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;ustom pages:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Printing selected pages:&lt;/b&gt;&lt;br&gt;The page specification box is enabled when the &lt;i&gt;custom pages&lt;/i&gt; mode is selected.  Enter page ranges separated by commas. Blank pages can be specified as page &lt;b&gt;0&lt;/b&gt;. The last page can be referred to as page &lt;b&gt;$&lt;/b&gt;.&lt;ul&gt;&lt;li&gt;Simple case: &lt;b&gt;1,2,10-12&lt;/b&gt;.&lt;/li&gt;&lt;li&gt;Printing multiple pages: &lt;b&gt;1,1,2,2&lt;/b&gt;.&lt;/li&gt;&lt;li&gt;Inserting a blank page: &lt;b&gt;1-10,0,11-$&lt;/b&gt;.&lt;/li&gt;&lt;li&gt;Printing in reverse: &lt;b&gt;$-1&lt;/b&gt;.&lt;/li&gt;&lt;/ul&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;GreyScale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send Image To:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printe&amp;r</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F&amp;ile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Command:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Print Destination:&lt;/b&gt;&lt;ul&gt;&lt;li&gt;Enter the file name when printing to a file.&lt;/li&gt;&lt;li&gt;Enter a print command to select a printer. Command line options are of course allowed. Command print commands include:&lt;br&gt;&lt;b&gt;lp -d&lt;/b&gt;&lt;i&gt;printername&lt;/i&gt;,&lt;br&gt;&lt;b&gt;lpr -P&lt;/b&gt;&lt;i&gt;printername&lt;/i&gt;,&lt;br&gt;&lt;b&gt;kprinter --stdin&lt;/b&gt;.&lt;/ul&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Postscript</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PostScript File format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;PostScript File (*.ps)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Encapsulated PostScript File (*.eps)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;PostScript file format:&lt;/b&gt;These options are enabled when printing to a file.&lt;ul&gt;&lt;li&gt;&lt;i&gt;Postscript files&lt;/i&gt; provide more configuration options.&lt;/li&gt;&lt;li&gt;&lt;i&gt;Encapsulated PostScript files&lt;/i&gt; are nicely imported by other applications. On the other hand they can only contain a single page with predefined scaling.&lt;/li&gt;&lt;/ul&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PostScript language level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level &amp;1 (almost obsolete)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level &amp;2 (default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level &amp;3 (might print faster)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;PostScript language level:&lt;/b&gt;&lt;br&gt;Level 1 is only useful with very old printers. Level 2 works with most printers. Level 3 might print faster on recent color printers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Scaling:&lt;/b&gt;&lt;br&gt;Option &lt;i&gt;scale to fit&lt;/i&gt; accomodates whetever paper size your printer uses. Option &lt;i&gt;one to one&lt;/i&gt; attempts to reproduce the initial document size.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Po&amp;rtrait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Landscape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Orientation:&lt;/b&gt;&lt;br&gt;Automatic orientation chooses portrait or landscape on a page per page basis.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print image &amp;frame</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print &amp;crop marks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Marks:&lt;/b&gt;&lt;br&gt;The image frame is useful to delimit the page area. The crop marks are useful to cut the paper to the correct size.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Booklet options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print sheets suitable for folding booklet(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Each booklet contains</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>at most</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sheet(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>as many sheets as needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Producing booklets:&lt;/b&gt;&lt;br&gt;The booklet mode prints the selected pages as sheets suitable for folding one or several booklets. Several booklets might be produced when a maximum number of sheets per booklet is specified. You can either use a duplex printer or print rectos and versos separately.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Advanced booklet options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift rectos and versos by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> points.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center margins:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>plus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>/100</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>per sheet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Advanced booklet options:&lt;/b&gt;&lt;br&gt;Shifting rectos and versos is useful with poorly aligned duplex printers. The center margins determine how much space is left between the pages to fold the sheets. This space slowly increases from the inner sheet to the outer sheet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDSavedFilesDialog</name>
    <message>
        <source>This will create the following files (plus additional included files) into the directory &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will create the following files into the directory &apos;%1&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDSearchDialog</name>
    <message>
        <source>&amp;Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End of document reached. Continue from the beginning?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginning of document reached. Continue from the end?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End of page reached. Continue from the beginning?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Beginning of page reached. Continue from the end?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu Search Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This page does not contain textual information,
which means that either the creator of this document
did not run an OCR engine on it, or the OCR engine
did not recognize any text on this page.

The search is impossible.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search string not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu: Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search &amp;all pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Whole word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search &amp;backwards</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading page WWWWWWW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After looking through every page of this document,
we have found that none of them contain
textual information. This means that either the document
creator did not run an OCR engine on this document,
or the OCR engine did not recognize any text.

The search is impossible.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading page %1: %2%...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDSetZoom</name>
    <message>
        <source>DjVu: Set Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDTBarModePiece</name>
    <message>
        <source>Fit Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stretch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pane Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Selected Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Text in Selected Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stick</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDTBarNavPiece</name>
    <message>
        <source>Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forward</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDTBarPrintPiece</name>
    <message>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDTBarRotatePiece</name>
    <message>
        <source>Rotate +90</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate -90</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDTbarPrefs</name>
    <message>
        <source>Enable toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar is always visible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar hide delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;Toolbar:&lt;/b&gt;&lt;br&gt;Checking the &lt;i&gt;enable toolbar&lt;/i&gt; box adds a toolbar at the bottom of each DjVu image. Checking the &lt;i&gt;always visible&lt;/i&gt; box makes the toolbar visible at all times. Otherwise the toolbar appears when the mouse pointer comes close to the bottom of the image and remains visible until the specified delay expires.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDThumbnails</name>
    <message>
        <source>Page </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDViewer</name>
    <message>
        <source>Printing prohibited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printing of this image
has been disallowed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upgrade DjVu now!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are using an obsolete version of the
DjVu plugin. To install the newest
version click &quot;Download&quot; and follow the
instructions.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are using an obsolete version of the
DjVu plugin. Please upgrade the viewer to
view this document.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This DjVu document uses an inferior
technology, which is no longer supported.
Please send a flame to the webmaster who
uses outdated tools.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page decoding done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finish printing first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please close the Print dialog first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requesting URL </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subprocess diagnostics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Black and &amp;White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Foreground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full &amp;Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Custom...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One &amp;to One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stretch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit &amp;Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit &amp;Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left side down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upside down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right side down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rotation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Previous Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;First Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Last Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Goto Page...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Navigate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page &amp;Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document In&amp;formation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save D&amp;ocument As ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save P&amp;age As ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Export page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Pa&amp;ge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print &amp;Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;references ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A&amp;bout DjVu ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu: Page Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjView - </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDViewerPrefs</name>
    <message>
        <source>DjVu: Viewer Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gamma</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lens</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optimization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDViewerShell</name>
    <message>
        <source>Select &quot;File&quot; and then &quot;Open&quot; to load a DjVu file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to open file &apos;%1&apos; for reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to locate file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu: Select DjVu file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to open file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DjVu Standalone Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save D&amp;ocument As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save P&amp;age As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Export page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P&amp;rint Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pr&amp;int Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Black and &amp;White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Foreground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full &amp;Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Custom...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One &amp;to One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stretch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit &amp;Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit &amp;Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Previous Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;+10 Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;-10 Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;First Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Last Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Goto Page...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Navigate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Page Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Document Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show &amp;Bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDWPaper</name>
    <message>
        <source>DjVu Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QDWelcome</name>
    <message>
        <source>Welcome to the DjVu Plug-in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust gamma correction, caches, etc.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn how to use DjVu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Credit and links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>These functions and many others can be
accessed from within a DjVu document
by clicking the right mouse button.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Never show this window again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMimeChecker</name>
    <message>
        <source>Please restart Netscape for the changes to take effect</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QeExcMessage</name>
    <message>
        <source>&amp;Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide &amp;Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Function name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QeFileDialog</name>
    <message>
        <source>You should select a regular file,
not a pipe, socket or device file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file &apos;%1&apos; for reading.
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File &apos;%1&apos; already exists.
Are you sure you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file &apos;%1&apos; for writing.
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to stat file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select directory for page files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a name for the DjVu page...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
